<?php
// Version: 2.0 RC1; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';
	
	//Theme Owner Copyright
	if(!function_exists('theme_owner_copyright') or !function_exists('theme_owner_copyright_error_disp'))
		fatal_error('Fatal Error');

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '2.0 RC1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = false;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = false;

	/* Show sticky and lock status separate from topic icons? */
	$settings['separate_sticky_lock'] = true;

	/* Does this theme use the strict doctype? */
	$settings['strict_doctype'] = false;

	/* Does this theme use post previews on the message index? */
	$settings['message_index_preview'] = false;
	
	/* Set the following variable to true if this theme requires the optional theme strings file to be loaded. */
	$settings['require_theme_strings'] = true;
}

// The main sub template above the content.
function template_html_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title_html_safe'], '" />
	<meta name="keywords" content="', $context['meta_keywords'], '" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/script.js?rc1"></script>
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/theme.js?rc1"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_default_theme_url = "', $settings['default_theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '
		if (confirm("' . $txt['show_personal_messages'] . '"))
			window.open(smf_prepareScriptUrl(smf_scripturl) + "action=pm");' : '', '
		var ajax_notification_text = "', $txt['ajax_in_progress'], '";
		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";
	// ]]></script>
	<title>', $context['page_title_html_safe'], '</title>';

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex" />';

	// The ?rc1 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style', $context['theme_variant'], '.css?rc1" />';

	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/print.css?rc1" media="print" />';

	// IE7 needs some fixes for styles.
	if ($context['browser']['is_ie7'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ie7.css" />';
	// ..and IE6!
	elseif ($context['browser']['is_ie6'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ie6.css" />';
	// Firefox - all versions - too!
	elseif ($context['browser']['is_firefox'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ff.css" />';

	// RTL languages require an additional stylesheet.
	if ($context['right_to_left'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/rtl.css" />';
	
	echo'
	<!--[if IE 6]>
	<script language="JavaScript" charset="', $context['character_set'], '" type="text/javascript" src="', $settings['theme_url'], '/png.js"></script>
	<![endif]-->';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
	{
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);
		$options['collapse_header_ic'] = !empty($_COOKIE['upshrinkIC']);
	}

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		// Create the main header object.
		var mainHeader = new smfToggle("upshrink", ', empty($options['collapse_header']) ? 'false' : 'true', ');
		mainHeader.useCookie(', $context['user']['is_guest'] ? 1 : 0, ');
		mainHeader.setOptions("collapse_header", "', $context['session_id'], '");
		mainHeader.addToggleImage("upshrink", "/upshrink.gif", "/upshrink2.gif");
		mainHeader.addTogglePanel("user_section");
		mainHeader.addTogglePanel("news_section");
	// ]]></script>';

	echo '
		<script charset="', $context['character_set'], '" language="JavaScript" type="text/javascript" src="', $settings['theme_url'], '/mootools.js"></script>
		<script charset="', $context['character_set'], '" language="JavaScript" type="text/javascript" src="', $settings['theme_url'], '/imageMenu.js"></script>
		<script charset="', $context['character_set'], '" language="JavaScript" type="text/javascript" src="', $settings['theme_url'], '/kwick.js"></script>
</head>
<body>';
}

function template_body_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
<div class="ust">
	<div style="margin:auto;width:910px;">
		<table style="padding-top:15px;" width="100%" border="0" cellspacing="0" cellpadding="0">
			<tr>
				<td align="left" valign="middle" style="font-size:11px; font-family:Arial, Helvetica, sans-serif; font-weight:bold;">';
	if ($context['user']['is_logged'])
	{
		// Only tell them about their messages if they can read their messages!
		if ($context['allow_pm'])
		{
			if ($context['user']['unread_messages'] > 0)
			{
				echo '
					<img alt="" src="'.$settings['images_url'].'/pm1.gif"/> <span class="pmesaj"><a href="', $scripturl, '?action=pm">' ,$txt['pm_short'], ' (', $context['user']['messages'], '/<font color="#ff0000">', $context['user']['unread_messages'], '</font>)</a></span>';
			}
			elseif ($context['user']['unread_messages'] == 0)
			{
				echo '
					<img alt="" src="'.$settings['images_url'].'/pm.gif"/> <span class="pmesaj"><a href="', $scripturl, '?action=pm">' ,$txt['pm_short'], ' (', $context['user']['messages'], '/<font color="#ff0000">', $context['user']['unread_messages'], '</font>)</a></span>';
			}
		}
			echo '
					&nbsp;<img alt="" src="'.$settings['images_url'].'/yenimesaj.gif" /> <span class="yenimesaj"><a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a></span> &nbsp;<img alt="" src="'.$settings['images_url'].'/mesajcevap.gif" /> <span class="mesajcevap"><a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a></span>';

		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo '
				&nbsp;<img alt="" src="', $settings['images_url'], '/onay.gif" /> <font style="font-size: 8pt"><a href="', $scripturl, '?action=admin;area=viewmembers;sa=browse;type=approve">', $context['unapproved_members'], ' ' , $txt['uyeonay'], '</a>';

		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '
				<b>', $txt['maintain_mode_on'], '</b><br />';

		// Show the total time logged in?
		if (!empty($context['user']['total_time_logged_in']))
		{
			echo '
				', $txt['totalTimeLogged1'];

			// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];
	
			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];

			// But, let's always show minutes - Time wasted here: 0 minutes ;).
				echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '<br />';
		}
	}
	if ($context['user']['is_guest'])
	{ 
		echo '
				<img alt="" src="'.$settings['images_url'].'/uyeol.gif"/> <span class="uyeol"><a href="', $scripturl, '?action=register">',$txt['register'], '</a></span> &nbsp;<img alt="" src="'.$settings['images_url'].'/sifremiunutum.gif" /> <span class="sifremi"><a href="', $scripturl, '?action=reminder">',$txt['forgot_your_password'], '</a></span> &nbsp;<img alt="" src="'.$settings['images_url'].'/aktivasyon.gif" /> <span class="aktivasyon"><a href="', $scripturl, '?action=activate">',$txt['activate'], '</a></span>';
	}
		echo '
				</td>
				<td align="right" valign="middle"  style="font-size:11px; font-family:Arial, Helvetica, sans-serif; font-weight:bold;">';
	if($context['user']['is_logged'])
	{
		echo '
					<span style="font-size: 100%;">
						<font color="#efefef" style="font-size: 8pt">
							' ,$txt['hello_member_ndt'], '&nbsp;&nbsp;
						</font>
						<font style="font-size: 9pt" color="#0f5086"><b>', $context['user']['name'] , '</b></font>
					</span> &nbsp;<a href="', $scripturl, '?action=logout;',  $context['session_var'], '=', $context['session_id'], '" ><img alt="" src="', $settings['images_url'], '/cikis.gif"  style="position:relative;top: -1px;vertical-align: middle;"/></a>&nbsp;';
	}
	if ($context['user']['is_guest'])
	{
		echo '
					<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/sha1.js"></script>
					<form action="', $scripturl, '?action=login2" id="guest_form" method="post" accept-charset="', $context['character_set'], '"  style="margin: 0px 0px 0px 0px;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
						<input value="User Name" onclick="this.value=\'\';" type="text" name="user" size="10" style="font-size:8px;" /> &nbsp;<input size="10" type="password" value="pass" onclick="this.value=\'\';" style=" font-size:8px;" name="passwrd" /> &nbsp;
						<select name="cookielength">
							<option value="60">', $txt['one_hour'], '</option>
							<option value="1440">', $txt['one_day'], '</option>
							<option value="10080">', $txt['one_week'], '</option>
							<option value="43200">', $txt['one_month'], '</option>
							<option value="-1" selected="selected">', $txt['forever'], '</option>
						</select> &nbsp;
						<input type="image" src="', $settings['images_url'], '/giris.gif" style="position:relative;top: -1px;vertical-align: middle;" />&nbsp;
						<input type="hidden" name="hash_passwrd" value="" />
					</form>';
	}
			echo'
				</td>
			</tr>
		</table>
	</div>
</div>
<div class="orta">
	<div style="margin:auto;width:910px;">
		<table cellspacing="0" cellpadding="3" border="0" align="center" width="100%">
			<tr>
				<td align="left"><img src="', $settings['images_url'], '/logo.png" alt="" /></td>
				<td align="right">', (!empty($settings['header_ads']) ? $settings['header_ads'] : ''), '</td>
			</tr>
		</table>
	</div>
</div>
<div class="orta">
	<div class="bg">', template_menu(), '</div>
</div>
<div class="orta">
	<div style="margin:auto;width:910px;">
		<div id="wrapper" style="padding: 1ex 0px 2ex 0px;">
			<div id="leftcolumn">
			', theme_linktree();
}

function template_body_below()
{
	global $context, $settings, $options, $scripturl, $txt, $ownerc;
	echo '
			</div>
			<div id="rightcolumn">
				<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px; margin-top:32px;">
					<tr>
						<td style="padding: 5px 5px 5px 10px;" class="catbg_blue"> &nbsp;', $txt['search'], '</td>
					</tr>
					<tr class="windowbg">
						<td valign="middle" align="center" height="60">
							<form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '" style="margin: 0;">
							<div align="center">
								<input type="hidden" name="advanced" value="0" /><input type="text" name="search" style="width:160px;" size="25" /><br />
								<input type="submit" name="submit" value="', $txt['search'], '" />
							</div>
							</form>
						</td>
					</tr>
				</table>
				<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px;">
					<tr>
						<td style="padding: 5px 5px 5px 10px;" class="catbg_red"> &nbsp;' ,$txt['forum_stats'], '</td>
					</tr>
					<tr class="windowbg">
						<td valign="middle" align="center" height="60">
							<div align="left" class="smalltext">
								<img style="margin-right:5px;" src="' . $settings['images_url'] . '/on.gif" width="12" height="12" alt="' . $txt['new_posts'] . '"/><b>', $txt['total_posts'], ':</b>  ', $context['common_stats']['total_posts'], ' <br />
								<img style="margin-right:5px;" src="' . $settings['images_url'] . '/on.gif" width="12" height="12" alt="' . $txt['new_posts'] . '"/><b>', $txt['total_topics'], ':</b>  ', $context['common_stats']['total_topics'], '<br />
								<img style="margin-right:5px;" src="' . $settings['images_url'] . '/on.gif" width="12" height="12" alt="' . $txt['new_posts'] . '"/><b>', $txt['total_members'], ':</b>  ', $context['common_stats']['total_members'], '<br /> 
								<img style="margin-right:5px;" src="' . $settings['images_url'] . '/on.gif" width="12" height="12" alt="' . $txt['new_posts'] . '"/><b>', $txt['latest_member'], ': </b> ', $context['common_stats']['latest_member']['link'], '
							</div>
						</td>
					</tr>
				</table>
				<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px;">
					<tr>
						<td style="padding: 5px 5px 5px 10px;" class="catbg_yellow"> &nbsp;', $txt['advertisement'], '</td>
					</tr>
					<tr class="windowbg">
						<td valign="middle" align="center" height="60">
							', (!empty($settings['right_ads']) ? $settings['right_ads'] : ''), '
						</td>
					</tr>
				</table>
				<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px;">
					<tr>
						<td style="padding: 5px 5px 5px 10px;" class="catbg_green"> &nbsp;', $txt['news'], '</td>
					</tr>
					<tr class="windowbg">
						<td valign="middle" align="center" height="60">';
						if ($context['user']['is_logged'])
							echo (!empty($settings['sidebar_news']) ? $settings['sidebar_news'] : '');
						else
							echo $txt['welcome_guest'];
						echo'				
						</td>
					</tr>
				</table>
				<table border="0" width="100%" class="tborder" cellspacing="' , ($context['browser']['is_ie'] || $context['browser']['is_opera6']) ? '1' : '0' , '" cellpadding="4" style="margin-bottom: 10px;">
					<tr>
						<td style="padding: 5px 5px 5px 10px;" class="catbg_blue"> &nbsp;', $txt['site_links'], '</td>
					</tr>
					<tr class="windowbg">
						<td valign="top" align="left" height="60">
							', (!empty($settings['site_link']) && !empty($settings['site_title']) && !empty($settings['site_desc']) ? '<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link'] . '" title="'. $settings['site_title'] . '">'. $settings['site_desc'] . '</a><br />' : ''), '
							', (!empty($settings['site_link1']) && !empty($settings['site_title1']) && !empty($settings['site_desc1']) ? '<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link1'] . '" title="'. $settings['site_title1'] . '">'. $settings['site_desc1'] . '</a><br />' : ''), '
							', (!empty($settings['site_link2']) && !empty($settings['site_title2']) && !empty($settings['site_desc2']) ? '<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link2'] . '" title="'. $settings['site_title2'] . '">'. $settings['site_desc2'] . '</a><br />' : ''), '
							', (!empty($settings['site_link3']) && !empty($settings['site_title3']) && !empty($settings['site_desc3']) ? '<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link3'] . '" title="'. $settings['site_title3'] . '">'. $settings['site_desc3'] . '</a><br />' : ''), '
							', (!empty($settings['site_link4']) && !empty($settings['site_title4']) && !empty($settings['site_desc4']) ? '<img style="margin-right:5px;" src="' . $settings['images_url'] . '/ok.gif" alt=""/><a target="_blank" href="'. $settings['site_link4'] . '" title="'. $settings['site_title4'] . '">'. $settings['site_desc4'] . '</a><br />' : ''), '
						</td>
					</tr>
				</table>
			</div>
			<div style="clear:both;"></div>
		</div>
	</div>
</div>
<div class="alt"></div>
<div style="font-color:#efefef;">
	<div class="footerarea" style="font-color:#efefef;text-align: center; padding-bottom: 1ex;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">
		<table cellspacing="0" cellpadding="3" border="0" align="center" width="925">
			<tr>
				<td width="50%" valign="middle" align="left">
					', theme_copyright(), '
				</td>
				<td style="font-color:#efefef;" width="50%" valign="middle" align="right">
					<div id="footerarea" >', theme_owner_copyright(), '',$txt['theme_cp2'],'</div>
				</td>
			</tr>
		</table>';
		if(!isset($ownerc['trig']) || $ownerc['newText'] <>'' .$txt['theme_error_doc']. '')
			theme_owner_copyright('opentrigger');

		// Show the load time?
		if ($context['show_load_time'])
			echo '
				<span class="smalltext">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</span>';
	echo '
	</div>
</div>';
}

function template_html_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree($force_show = false)
{
	global $context, $settings, $options, $shown_linktree;

	// If linktree is empty, just return - also allow an override.
	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))
		return;

	//!!! Temporarily don't do it twice.
	if (!empty($shown_linktree))
		return;
	$shown_linktree = true;

	echo '<div class="nav" style="font-size: smaller; margin-bottom: 2ex; margin-top: 2ex;">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;>&nbsp;';
	}
	echo '
	</div>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

   echo '
	<div id="kwick">
		<ul class="kwicks">';
	$i = 0;

	foreach ($context['menu_buttons'] as $act => $button)
	{
		$i++;
		echo '
			<li><a href="', $button['href'], '" class="kwick opt', $i, '">', $settings['use_image_buttons'] ? '<img src="' . $settings['lang_images_url'] . '/' . $act . '.gif" alt="' . $button['title'] . '" border="0" />' : $button['title'], '</a></li>';
	}

	echo '
		</ul>
	</div>';
}

// Generate a strip of buttons, out of buttons.
function template_button_strip($button_strip, $direction = 'top', $custom_td = '')
{
	global $settings, $context, $txt, $scripturl;

	if (empty($button_strip))
		return '';

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
		if (!isset($value['test']) || !empty($context[$value['test']]))
			$buttons[] = '<a href="' . $value['url'] . '"' . (isset($value['content']) ? $value['content'] : (isset($value['active']) ? ' class="active"' : '') . (isset($value['custom']) ? ' ' . $value['custom'] : '') . '>' . ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . ($value['lang'] ? $context['user']['language'] . '/' : '') . $value['image'] . '" alt="' . $txt[$value['text']] . '" border="0" />' : $txt[$value['text']])) . '</a>';

	if (empty($button_strip))
		return '';

	echo '
		<div ', $custom_td, '>', implode($context['menu_separator'], $buttons) , '</div>';
}

function theme_owner_copyright($trig = null)
{
	global $ownerc, $txt;

	if(isset($trig) && !empty($trig) && $trig == 'opentrigger')
		echo theme_owner_copyright_error_disp();
	
		$ownerc['ctext'] = '' .$txt['theme_cp']. '';
		$ownerc['trig'] = true;
		
		theme_owner_copyright_error_disp('' .$txt['theme_error_doc']. '');
		
		return $ownerc['ctext'];
}

function theme_owner_copyright_error_disp($nums=null)
{
	global $ownerc, $txt;
	
	if(isset($nums) && !empty($nums) && $nums == '' .$txt['theme_error_doc']. '')
	{
		$ownerc['ctexttrig'] = strtolower(substr($ownerc['ctext'],-5));
		$ownerc['newText'] = $ownerc['ctexttrig'][4].$ownerc['ctexttrig'][3].$ownerc['ctexttrig'][2].$ownerc['ctexttrig'][1].$ownerc['ctexttrig'][0];
		return true;
	}
	else
	{
		$dispmsg = '<script language="JavaScript" type="text/javascript">alert("'. $txt['theme_error']. '");</script>
		<div style="background: red;border: 10px solid orange;">'. $txt['theme_error']. '</div>';
		return $dispmsg;
	}	
}

?>